@@ -2,7 +2,9 @@
 
 (when (locate-library "mhc")
   (setq mhc-use-wide-scope 14)
-  (setq mhc-file-line-status-strings '(" Mhc" . " MHC"))
+;;;  (setq mhc-use-wide-scope 'week)
+;;;  (setq mhc-use-wide-scope 'wide)
+;;;  (setq mhc-use-wide-scope nil)
   (global-set-key "\C-cI" 'mhc-import)
   (eval-after-load "mhc-draft"
     (quote
